import React from 'react'

import ListDetails from '../list/details'
import ListPosters from '../list/posters'
import Loader from '../loader/loader'
import ShowButtons from './listButtons'

export default class ShowList extends React.Component {
  handleParams(props = this.props) {
    // Check if the URL to fetch is in the props
    if (props.showsUrl) {
      this.props.fetchShows(props.showsUrl);
      return
    }

    // Check for URL parameters
    if (!props.params) {
      return
    }

    // Search param
    if  (props.params.search && props.params.search !== "") {
      this.props.searchShows({
        key: this.props.params.search
      });
      return
    }
  }
  componentWillMount() {
    this.handleParams();
  }
  componentWillUpdate(nextProps, nextState) {
    // No params
    if (!nextProps.params) {
      return
    }

    // Search field changed
    if (this.props.params.search
      && (this.props.params.search !== nextProps.params.search)
      && (nextProps.params.search !== "")) {
      this.handleParams(nextProps);
      return
    }
  }
  render() {
    const shows = this.props.showStore.shows;
    const selectedShowId = this.props.showStore.selectedImdbId;
    let index = shows.map((el) => el.imdb_id).indexOf(selectedShowId);
    if (index === -1) {
      index = 0;
    }
    const selectedShow = shows[index];

    // Loading
    if (this.props.showStore.loading) {
      return (<Loader />);
    }

    return (
      <div className="row" id="container">
        <ListPosters
          data={shows}
          type="shows"
          formModel="showStore"
          filterControlModel="showStore.filter"
          filterControlPlaceHolder="Filter shows..."
          fetchExploreOptions={this.props.getShowExploreOptions}
          exploreOptions={this.props.showStore.exploreOptions}
          explore={this.props.exploreShows}
          selectedImdbId={selectedShowId}
          filter={this.props.showStore.filter}
          perPage={this.props.showStore.perPage}
          onClick={this.props.selectShow}
          router={this.props.router}
          params={this.props.params}
        />
        {selectedShow &&
          <ListDetails data={selectedShow} >
            <ShowButtons
              show={selectedShow}
              deleteFromWishlist={this.props.deleteShowFromWishlist}
              addToWishlist={this.props.addShowToWishlist}
              getDetails={this.props.getShowDetails}
              fetching={this.props.showStore.getDetails}
            />
          </ListDetails>
        }
      </div>
    );
  }
}
